# Changelog

## [0.1.3a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.1.3a1) (2024-09-23)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.1.2...0.1.3a1)

**Merged pull requests:**

- fix:wait while speaking [\#238](https://github.com/OpenVoiceOS/OVOS-workshop/pull/238) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
